Welcome to Parfun's documentation!
==================================

**Parfun** is a lightweight and user-friendly Python library designed to help users run Python functions in parallel
with ease.

Even with minimal knowledge of parallelism or distributed systems, users can significantly speed up their Python code
using Parfun.

Parfun supports multiple execution backends, including Python's built-in
`multiprocessing <https://docs.python.org/3/library/multiprocessing.html>`_, as well as
`Scaler <https://github.com/finos/opengris-scaler/>`_ and `Dask <https://www.dask.org/>`_.


Content
=======

.. toctree::
   :maxdepth: 2

   tutorials/quickstart
   tutorials/examples
   tutorials/implementation_details
   api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
